@@ -49,7 +49,66 @@ stopifnot(
   identical(where$d, globalenv())
 )
 
-message(" ** globalsOf() w/ globals in local functions:")
+globals_i <- globalsOf(function(x) x <- x)
+print(globals_i)
+globals_i <- cleanup(globals_i)
+str(globals_i)
+assert_identical_sets(names(globals_i), character(0L))
+where <- attr(globals_i, "where")
+stopifnot(
+  length(where) == length(globals_i),
+  identical(where, setNames(list(), character(0L)))
+)
+
+
+globals_i <- globalsOf(function(x) x[1] <- 0)
+print(globals_i)
+globals_i <- cleanup(globals_i)
+str(globals_i)
+assert_identical_sets(names(globals_i), character(0L))
+where <- attr(globals_i, "where")
+stopifnot(
+  length(where) == length(globals_i),
+  identical(where, setNames(list(), character(0L)))
+)
+
+globals_i <- globalsOf(function(x) a <- x$a)
+print(globals_i)
+globals_i <- cleanup(globals_i)
+str(globals_i)
+assert_identical_sets(names(globals_i), character(0L))
+where <- attr(globals_i, "where")
+stopifnot(
+  length(where) == length(globals_i),
+  identical(where, setNames(list(), character(0L)))
+)
+
+globals_i <- globalsOf(function(...) args <- list(...))
+print(globals_i)
+globals_i <- cleanup(globals_i)
+str(globals_i)
+assert_identical_sets(names(globals_i), character(0L))
+where <- attr(globals_i, "where")
+stopifnot(
+  length(where) == length(globals_i),
+  identical(where, setNames(list(), character(0L)))
+)
+
+
+x <- 1
+globals_i <- globalsOf({ function(x) x; x }, substitute = TRUE)
+print(globals_i)
+globals_i <- cleanup(globals_i)
+str(globals_i)
+assert_identical_sets(names(globals_i), "x")
+where <- attr(globals_i, "where")
+stopifnot(
+  length(where) == length(globals_i)
+)
+
+
+
+message(" ** globalsOf() w/ globals in functions:")
 
 a <- 1
 bar <- function(x) x - a
